@@ -157,8 +157,14 @@ class Quip:
             current_folder = os.getcwd()
             template_path = os.path.join(current_folder, "src", "templates", "template.json")
             if os.path.exists(template_path):
-                _json = self.read_template_json(template_path=template_path)
-                args.name = _json["name"]
+                args.name = os.path.basename(current_folder)
+                # _json = self.read_template_json(template_path=template_path)
+                # template = (_json["templateType"] == "Script")
+                # if template:
+                #     args.name = "ut-" + _json["name"]
+                # else:
+                #     args.name = "ue-" + _json["name"]
+
                 self.in_project_folder = True
             else:
                 logging.error("You are not in a project folder. Please specify the project name.")
@@ -217,10 +223,13 @@ class Quip:
                     self.download_template()
             self.dump_fields(write=True)
         elif action == "build":
-            if not self.args.template:
-                logging.error("This action only possible with --template option. For extensions use 'uip build' command.")
-                sys.exit(1)
-            self.build_zip(self.project_name)
+            if self.args.template:
+                self.build_zip(self.project_name)
+            else:
+                self.run_uip("build")
+                self.curr_version = vb.find_current_version(version_files=self._version_files)
+                if len(self.curr_version) == 1:
+                    self.rename_build_package(self.curr_version[0])
         elif action == "config":
             if not self.uip_global_config.get("new", False):
                 QuipGlobalConfig().check_config(self.uip_global_config)
@@ -296,6 +305,8 @@ class Quip:
         if not self.args.template:
             self.update_extension_yaml(self.project_name)
             self.update_uip_config(self.project_name)
+        else:
+            self.update_script_config(self.project_name)
         self.update_template_json(self.project_name, update_uuid, update_new_uuid)
 
     def update_rename_scripts(self):
@@ -757,6 +768,9 @@ class Quip:
         elif action == "pull":
             need_pass = True
             command = f'''uip pull -i {self._global_conf_uip["url"]} -u {self._global_conf_uip["userid"]}'''
+        elif action == "build":
+            need_pass = False
+            command = f'''uip build -a'''
 
         if need_pass:
             uac_pass = getpass(prompt=f'''Enter password for {self._global_conf_uip["userid"]}: ''')
@@ -784,6 +798,17 @@ class Quip:
                     print(line)
             cprint(f"==============", color="yellow")
             
+    def rename_build_package(self, version):
+        package_folder = self.join_path("dist", "package_build")
+        for filename in os.listdir(package_folder):
+            if filename.endswith("universal_template.zip"):
+                new_filename = filename.replace("universal_template.zip", f"universal_template_{version}.zip")
+                new_filepath = self.join_path("dist", "package_build", new_filename)
+                if os.path.exists(new_filepath):
+                    shutil.move(self.join_path("dist", "package_build", filename), new_filepath)
+                else:
+                    os.rename(self.join_path("dist", "package_build", filename), new_filepath)
+                cprint(f"File Renamed: {filename} => {new_filename}", "yellow")
 
     def update_extension_yaml(self, project_name):
         logging.info("Updating extension.yml file")
@@ -810,6 +835,22 @@ class Quip:
         else:
             logging.error(f"ERROR: uip.yml file is missing! Path= {config}")
             sys.exit(1)
+    
+    def update_script_config(self, project_name):
+        logging.info("Updating script.yml file")
+        config = self.join_path("script.yml")
+        
+        if os.path.exists(config):
+            with open(config) as f:
+                _config = yaml.safe_load(f)
+
+            with open(config, "w") as f:
+                _config["script"]["name"] = project_name
+                yaml.dump(_config, f, sort_keys=False)
+                logging.debug("script.yml file is updated")
+        else:
+            logging.error(f"ERROR: script.yml file is missing! Path= {config}")
+            sys.exit(1)
 
     def read_template_json(self, template_path):
         logging.info("Reading template.json file")
